TransactionStoreError

Enum TransactionStoreError 

#[non_exhaustive]
pub enum TransactionStoreError {
Show 13 variants Duplicate { id: TransactionId, }, NotFound { id: TransactionId, }, StateConflict { id: TransactionId, expected: TransactionState, actual: TransactionState, }, Transition(TransitionError), ApprovalBindingMismatch { requested: TransactionId, bound: TransactionId, }, MissingApproval { id: TransactionId, }, ApprovalExpired { id: TransactionId, expired_at_unix_ms: u64, observed_at_unix_ms: u64, }, NotReservable { id: TransactionId, actual: TransactionState, }, PersistentIo { operation: &'static str, kind: ErrorKind, }, PersistentCorrupt { offset: u64, reason: &'static str, }, PersistentLogLimit { observed: u64, maximum: u64, }, PersistentRecordLimit { observed: usize, maximum: usize, }, Poisoned,
}
Atomic transaction-store failure.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Duplicate

The transaction ID already exists.

Fields

id: TransactionId

Duplicate ID.



NotFound

No record has this ID.

Fields

id: TransactionId

Missing ID.



StateConflict

Compare-and-transition observed another state.

Fields

id: TransactionId

Transaction ID.

expected: TransactionState

Required current state.

actual: TransactionState

State actually observed.



Transition(TransitionError)

The requested state edge is invalid.



ApprovalBindingMismatch

A grant for another exact artifact was presented.

Fields

requested: TransactionId

Transaction the caller attempted to approve.

bound: TransactionId

Transaction actually covered by the grant.



MissingApproval

An approved state lacked its grant and therefore failed closed.

Fields

id: TransactionId

Affected transaction.



ApprovalExpired

Approval expired and the record was moved to Expired.

Fields

id: TransactionId

Affected transaction.

expired_at_unix_ms: u64

Exclusive grant expiry.

observed_at_unix_ms: u64

Time supplied to reservation.



NotReservable

Current state can never win a new reservation.

Fields

id: TransactionId

Affected transaction.

actual: TransactionState

State actually observed.



PersistentIo

Durable state-file or cross-process lock I/O failed.

Fields

operation: &'static str

Stable operation label.

kind: ErrorKind

Portable operating-system error category.



PersistentCorrupt

Durable state bytes failed structural, checksum, or lifecycle validation.

Fields

offset: u64

Byte offset at which validation failed.

reason: &'static str

Stable corruption reason.



PersistentLogLimit

The append-only durable log exceeded its configured byte bound.

Fields

observed: u64

Bytes the next durable state would require.

maximum: u64

Configured byte ceiling.



PersistentRecordLimit

Unique durable transaction count exceeded its configured bound.

Fields

observed: usize

Unique records the operation would retain.

maximum: usize

Configured record ceiling.



Poisoned

Another thread panicked while mutating the in-memory reference backend.